@@ -1,17 +1,32 @@
+// Copyright 2025 Block, Inc.
+// SPDX-License-Identifier: Apache-2.0
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
 package cli
 
 import (
 	"crypto/tls"
-	"io/ioutil"
 	"net/http"
 	"net/http/httptest"
 	"os"
 	"regexp"
 	"testing"
 
-	"github.com/square/certigo/cli/terminal"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
+
+	"github.com/square/certigo/cli/terminal"
 )
 
 // certstrap init --curve P-256 --cn "Localhost Root" --expires "20 years"
@@ -170,7 +185,7 @@ Found 1 valid certificate chain(s):
 
 // Test basic dump functionality:  Dump a cert
 func TestDump(t *testing.T) {
-	tmpfile, err := ioutil.TempFile("", t.Name())
+	tmpfile, err := os.CreateTemp("", t.Name())
 	require.NoError(t, err)
 	defer os.Remove(tmpfile.Name())
 
@@ -195,7 +210,7 @@ func TestDumpMissingFile(t *testing.T) {
 }
 
 func TestConnect(t *testing.T) {
-	rootPath, err := ioutil.TempFile("", t.Name())
+	rootPath, err := os.CreateTemp("", t.Name())
 	require.NoError(t, err)
 	defer os.Remove(rootPath.Name())
 
